==> com.liferay.source.formatter-1.0.581-sources-commercial.jar: com/liferay/source/formatter/checks/JavaCleanUpMethodSuperCleanUpCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.source.formatter.checks.util.SourceUtil;
import com.liferay.source.formatter.parser.JavaMethod;
import com.liferay.source.formatter.parser.JavaSignature;
import com.liferay.source.formatter.parser.JavaTerm;

import java.util.Objects;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Peter Shin
 */
public class JavaCleanUpMethodSuperCleanUpCheck extends BaseJavaTermCheck {

	@Override
	protected String doProcess(
		String fileName, String absolutePath, JavaTerm javaTerm,
		String fileContent) {

		if (!fileName.endsWith("Tag.java")) {
			return javaTerm.getContent();
		}

		JavaMethod javaMethod = (JavaMethod)javaTerm;

		if (!Objects.equals(javaMethod.getName(), "cleanUp") ||
			!javaMethod.hasAnnotation("Override")) {

			return javaMethod.getContent();
		}

		JavaSignature javaSignature = javaMethod.getSignature();

		if (!Objects.equals(javaSignature.getReturnType(), StringPool.BLANK)) {
			return javaMethod.getContent();
		}

		String javaMethodContent = javaMethod.getContent();

		String regex = StringBundler.concat(
			"(", SourceUtil.getIndent(javaMethodContent),
			javaMethod.getAccessModifier(),
			" .*?[;{]\\s*?\n)((\n*)([^\n]+)\n)?");

		Pattern pattern = Pattern.compile(regex, Pattern.DOTALL);

		Matcher matcher = pattern.matcher(javaMethodContent);

		if (!matcher.find()) {
			return javaMethodContent;
		}

		String firstLine = matcher.group(4);

		if (firstLine.contains("super.cleanUp();")) {
			return javaMethodContent;
		}

		String indent = SourceUtil.getIndent(firstLine);

		return StringUtil.replace(
			javaMethodContent, firstLine,
			indent + "super.cleanUp();\n\n" + firstLine);
	}

	@Override
	protected String[] getCheckableJavaTermNames() {
		return new String[] {JAVA_METHOD};
	}

}

==> com.liferay.source.formatter-1.0.1177-sources-commercial.jar: com/liferay/source/formatter/checks/JavaCleanUpMethodSuperCleanUpCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.petra.string.StringBundler;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.source.formatter.checks.util.SourceUtil;
import com.liferay.source.formatter.parser.JavaMethod;
import com.liferay.source.formatter.parser.JavaSignature;
import com.liferay.source.formatter.parser.JavaTerm;

import java.util.Objects;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Peter Shin
 */
public class JavaCleanUpMethodSuperCleanUpCheck extends BaseJavaTermCheck {

	@Override
	protected String doProcess(
		String fileName, String absolutePath, JavaTerm javaTerm,
		String fileContent) {

		if (!fileName.endsWith("Tag.java")) {
			return javaTerm.getContent();
		}

		JavaMethod javaMethod = (JavaMethod)javaTerm;

		if (!Objects.equals(javaMethod.getName(), "cleanUp") ||
			!javaMethod.hasAnnotation("Override")) {

			return javaMethod.getContent();
		}

		JavaSignature javaSignature = javaMethod.getSignature();

		if (!Objects.equals(javaSignature.getReturnType(), StringPool.BLANK)) {
			return javaMethod.getContent();
		}

		String javaMethodContent = javaMethod.getContent();

		String regex = StringBundler.concat(
			"(", SourceUtil.getIndent(javaMethodContent),
			javaMethod.getAccessModifier(),
			" .*?[;{]\\s*?\n)((\n*)([^\n]+)\n)?");

		Pattern pattern = Pattern.compile(regex, Pattern.DOTALL);

		Matcher matcher = pattern.matcher(javaMethodContent);

		if (!matcher.find()) {
			return javaMethodContent;
		}

		String firstLine = matcher.group(4);

		if (firstLine.contains("super.cleanUp();")) {
			return javaMethodContent;
		}

		String indent = SourceUtil.getIndent(firstLine);

		return StringUtil.replace(
			javaMethodContent, firstLine,
			indent + "super.cleanUp();\n\n" + firstLine);
	}

	@Override
	protected String[] getCheckableJavaTermNames() {
		return new String[] {JAVA_METHOD};
	}

}
